documentFactory.TarDocumentStream

|  | ## Cheshire3 Object Model: Class TarDocumentStream

Module documentFactory :: Class TarDocumentStream

## Class TarDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
    MultipleDocumentStream --+
                             |
                            TarDocumentStream

Instance Methods

open_stream(self, stream)
_processFile(self, session, item)
_fetchStream(self, item)
_fetchName(self, item)
find_documents(self, session, cache=0)
Inherited from `MultipleDocumentStream`: `__init__` Inherited from `MultipleDocumentStream` (private): `_processFiles` Inherited from `BaseDocumentStream`: `fetch_document`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### open_stream(self, stream) | source code
Overrides: BaseDocumentStream.open_stream

### _processFile(self, session, item) | source code
Overrides: MultipleDocumentStream._processFile

### _fetchStream(self, item) | source code
Overrides: MultipleDocumentStream._fetchStream

### _fetchName(self, item) | source code
Overrides: MultipleDocumentStream._fetchName

### find_documents(self, session, cache=0) | source code